Chromium Code Reviews
chromiumcodereview-hr@appspot.gserviceaccount.com (chromiumcodereview-hr) | Please choose your nickname with Settings | Help | Chromium Project | Gerrit Changes | Sign out
(10226)

Unified Diff: chrome/renderer/module_system.h

Issue 9657026: Revert 125801 - Implement a module system for the extension bindings JS. (Closed) Base URL: svn://svn.chromium.org/chrome/trunk/src/
Patch Set: Created 8 years, 9 months ago
Use n/p to move between diff chunks; N/P to move between comments. Draft comments are only viewable by you.
Jump to:
View side-by-side diff with in-line comments
Download patch
« no previous file with comments | « chrome/renderer/extensions/webstore_bindings.cc ('k') | chrome/renderer/module_system.cc » ('j') | no next file with comments »
Expand Comments ('e') | Collapse Comments ('c') | Show Comments Hide Comments ('s')
Index: chrome/renderer/module_system.h
===================================================================
--- chrome/renderer/module_system.h (revision 125813)
+++ chrome/renderer/module_system.h (working copy)
@@ -9,15 +9,12 @@
#include "base/compiler_specific.h"
#include "base/memory/linked_ptr.h"
#include "base/memory/scoped_ptr.h"
-#include "base/string_piece.h"
#include "chrome/renderer/native_handler.h"
#include "v8/include/v8.h"
#include <map>
#include <string>
-class SourceMap;
-
// A module system for JS similar to node.js' require() function.
// Each module has three variables in the global scope:
// - exports, an object returned to dependencies who require() this
@@ -30,20 +27,10 @@
//
// Each module in a ModuleSystem is executed at most once and its exports
// object cached.
-//
-// Note that a ModuleSystem must be used only in conjunction with a single
-// v8::Context.
-// TODO(koz): Rename this to JavaScriptModuleSystem.
class ModuleSystem : public NativeHandler {
public:
- class SourceMap {
- public:
- virtual v8::Handle<v8::Value> GetSource(const std::string& name) = 0;
- virtual bool Contains(const std::string& name) = 0;
- };
-
// |source_map| is a weak pointer.
- explicit ModuleSystem(SourceMap* source_map);
+ explicit ModuleSystem(const std::map<std::string, std::string>* source_map);
virtual ~ModuleSystem();
// Require the specified module. This is the equivalent of calling
@@ -54,28 +41,19 @@
// calls to requireNative(|name|) from JS will return a new object created by
// |native_handler|.
void RegisterNativeHandler(const std::string& name,
- scoped_ptr<NativeHandler> native_handler);
+ scoped_ptr<NativeHandler> native_handler);
- // Executes |code| in the current context with |name| as the filename.
- void RunString(const std::string& code, const std::string& name);
-
- // When false |natives_enabled_| causes calls to GetNative() (the basis of
- // requireNative() in JS) to throw an exception.
- void set_natives_enabled(bool natives_enabled) {
- natives_enabled_ = natives_enabled;
- }
-
private:
- typedef std::map<std::string, linked_ptr<NativeHandler> > NativeHandlerMap;
-
// Ensure that require_ has been evaluated from require.js.
void EnsureRequireLoaded();
- // Run |code| in the current context with the name |name| used for stack
- // traces.
- v8::Handle<v8::Value> RunString(v8::Handle<v8::String> code,
- v8::Handle<v8::String> name);
+ // Run |code| in the current context.
+ v8::Handle<v8::Value> RunString(v8::Handle<v8::String> code);
+ // Run the given code in the current context.
+ // |args[0]| - the code to execute.
+ v8::Handle<v8::Value> Run(const v8::Arguments& args);
+
// Return the named source file stored in the source map.
// |args[0]| - the name of a source file in source_map_.
v8::Handle<v8::Value> GetSource(const v8::Arguments& args);
@@ -85,17 +63,12 @@
// |args[0]| - the name of a native handler object.
v8::Handle<v8::Value> GetNative(const v8::Arguments& args);
- base::StringPiece GetResource(int resource_id);
-
- // Throws an exception in the calling JS context.
- v8::Handle<v8::Value> ThrowException(const std::string& message);
-
// A map from module names to the JS source for that module. GetSource()
// performs a lookup on this map.
- SourceMap* source_map_;
+ const std::map<std::string, std::string>* source_map_;
+ typedef std::map<std::string, linked_ptr<NativeHandler> > NativeHandlerMap;
NativeHandlerMap native_handler_map_;
v8::Handle<v8::Function> require_;
- bool natives_enabled_;
};
#endif // CHROME_RENDERER_MODULE_SYSTEM_H_
« no previous file with comments | « chrome/renderer/extensions/webstore_bindings.cc ('k') | chrome/renderer/module_system.cc » ('j') | no next file with comments »

Powered by Google App Engine
This is Rietveld 408576698